#
# spec file for package python-wcmatch
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%{?python_enable_dependency_generator}
Name:           python-wcmatch
Version:        10.0
Release:        1.4
Summary:        Wildcard/glob file name matcher
License:        MIT
URL:            https://github.com/facelessuser/wcmatch
Source:         https://files.pythonhosted.org/packages/source/w/wcmatch/wcmatch-%{version}.tar.gz
BuildRequires:  %{python_module base > 3.6}
BuildRequires:  %{python_module bracex}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Wildcard Match provides an enhanced `fnmatch`, `glob`, and `pathlib` library in order to provide file matching and
globbing that more closely follows the features found in Bash. In some ways these libraries are similar to Python's
builtin libraries as they provide a similar interface to match, filter, and glob the file system. But they also include
a number of features found in Bash's globbing such as backslash escaping, brace expansion, extended glob pattern groups,
etc. They also add a number of new useful functions as well, such as `globmatch` which functions like `fnmatch`, but for
paths.

Wildcard Match also adds a file search utility called `wcmatch` that is built on top of `fnmatch` and `globmatch`. It
was originally written for [Rummage](https://github.com/facelessuser/Rummage), but split out into this project to be
used by other projects that may find its approach useful.

Bash is used as a guide when making decisions on behavior for `fnmatch` and `glob`. Behavior may differ from Bash
version to Bash version, but an attempt is made to keep Wildcard Match up with the latest relevant changes. With all of
this said, there may be a few corner cases in which we've intentionally chosen to not *exactly* mirror Bash. If an issue
is found where Wildcard Match seems to deviate in an illogical way, we'd love to hear about it in the
[issue tracker](https://github.com/facelessuser/wcmatch/issues).

%prep
%setup -q -n wcmatch-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%{python_sitelib}/wcmatch
%{python_sitelib}/wcmatch-%{version}.dist-info

%changelog
* Wed Nov 20 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 10.0:
  * NEW: Added GLOBSTARLONG which adds support for the Zsh style
  * ** which acts like ** with GLOBSTAR but but traverses
    symlinks.
  * NEW: pathlib.match will respect symlink rules (when the
    REALPATH flag is given). Hidden file rules will be respected at
    all times. Enable DOTALL to match hidden files.
  * NEW: Symlinks should not be traversed when GLOBSTAR is enabled
    unless FOLLOW is also enabled, but they should still be
    matched. Prior to this change, symlinks were not traversed and
    they were ignored from matching which contradicts how Bash
    works and could be confusing to users.
  * FIX: Fix some inconsistencies with globmatch and symlink
    handling when REALPATH is enabled.
- update to 9.0:
  * NEW: Remove deprecated function glob.raw_escape.
  * NEW: Officially support Python 3.13.
* Mon Jun 10 2024 Dirk Müller <dmueller@suse.com>
- update to 8.5.2:
  * Fix `pathlib` issue with inheritance on Python
    versions greater than 3.12.
  * Fix `EXTMATCH` case with `!(...)` patterns.
* Wed Mar 13 2024 Dirk Müller <dmueller@suse.com>
- update to 8.5.1:
  * Fix issue with type check failure in `wcmatch.glob`.
* Tue Jan  2 2024 Dirk Müller <dmueller@suse.com>
- update to 8.5:
  * Formally support Python 3.11 (no change).
  * Add support for Python 3.12 (`pathlib` changes).
  * Drop Python 3.7 support.
  * Fix handling of current directory when magic and
    non-magic patterns are mixed in `glob` pattern list.
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Mon Nov 21 2022 Johannes Kastl <kastl@b1-systems.de>
- update to 8.4.1:
  - FIX: Windows drive path separators should normalize like other path separators.
  - FIX: Fix a Windows pattern parsing issue that caused absolute paths with ambiguous drives to not parse correctly.
- update to 8.4.0:
  - NEW: Drop support for Python 3.6.
  - NEW: Switch to Hatch backend instead of Setuptools.
  - NEW: Add new exclude option to fnmatch, pathlib, and glob methods that allows exclusion patterns to be
    specified directly without needing to enable NEGATE and prepend patterns with !. exclude accepts a separate
    pattern or pattern list. exclude should not be used in conjunction with NEGATE. One or the other should be used.
- add _service file to easily download this
- change %%build to use hatchling
* Sun Jan 23 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- initial package for version 8.3.
